@@ -44,7 +44,7 @@ test_that("variance 2",{
                                  observations=unflat$obs.table,
                                  strat_formula=~1, convert_units=cu,
                                  er_est="O2"),
-                 "Using the O2 encounter rate variance estimator, assuming that sorting on Sample.Label is meaningful")
+                 "Using O2 or O3 encounter rate variance estimator, assuming that sorting on Sample.Label is meaningful")
 
   lr <- Nhat_O2[nrow(Nhat_O2), , drop=FALSE]
   expect_equal(lr$Abundance, 1022, tol=1e-1)
